package com.ruoyi.mall.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallAppAddress;

/**
 * app地址管理Mapper接口
 *
 * @author ruoyi
 * @date 2024-06-28
 */
public interface MallAppAddressMapper
{
    /**
     * 查询app地址管理
     *
     * @param addressId app地址管理主键
     * @return app地址管理
     */
    public MallAppAddress selectMallAppAddressByAddressId(Long addressId);

    /**
     * 查询app地址管理列表
     *
     * @param mallAppAddress app地址管理
     * @return app地址管理集合
     */
    public List<MallAppAddress> selectMallAppAddressList(MallAppAddress mallAppAddress);

    /**
     * 新增app地址管理
     *
     * @param mallAppAddress app地址管理
     * @return 结果
     */
    public int insertMallAppAddress(MallAppAddress mallAppAddress);

    /**
     * 修改app地址管理
     *
     * @param mallAppAddress app地址管理
     * @return 结果
     */
    public int updateMallAppAddress(MallAppAddress mallAppAddress);

    /**
     * 删除app地址管理
     *
     * @param addressId app地址管理主键
     * @return 结果
     */
    public int deleteMallAppAddressByAddressId(Long addressId);

    /**
     * 批量删除app地址管理
     *
     * @param addressIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallAppAddressByAddressIds(Long[] addressIds);

    /**
     * 查询app地址管理列表
     *
     * @param params 参数
     * @return app地址管理集合
     */
    public List<MallAppAddress> getAddressManageList(Map<String, Object> params);
}
